@@ -86,11 +86,11 @@ CzechAnalyzer::~CzechAnalyzer() {
 
 const HashSet<String> CzechAnalyzer::getDefaultStopSet() {
     static HashSet<String> stopSet;
-    if (!stopSet) {
+    LUCENE_RUN_ONCE(
         String stopWords(UTF8_TO_STRING(_CZECH_STOP_WORDS));
         Collection<String> words(StringUtils::split(stopWords, L"\n"));
         stopSet = HashSet<String>::newInstance(words.begin(), words.end());
-    }
+    );
     return stopSet;
 }
 
