@@ -420,6 +420,20 @@ int32_t StandardTokenizerImpl::getNextToken() {
     wchar_t* zzBufferL = zzBuffer.get();
     const wchar_t* zzCMapL = ZZ_CMAP();
 
+    // This code was originally written in Java, which uses UTF-16, and it can't
+    // correctly deal with 32bit wchar_t and characters outside of the Basic
+    // Multilingual Plane. As a workaround to prevent crashes, treat all
+    // characters above U+FFFF as letters in the tokenizer.
+    // See https://github.com/luceneplusplus/LucenePlusPlus/issues/57
+    const wchar_t zzCMapFallback = zzCMapL['A'];
+#ifdef LPP_UNICODE_CHAR_SIZE_4
+    #define zzCMap_at(n) ((n) > 0xFFFF ? zzCMapFallback : zzCMapL[n])
+#else
+    // If the 16-bit value is in [0xD800, 0xDFFF], it is part of a multi-byte 
+    // UTF-16 character and its UTF code point is > U+FFFF, so handle as above.
+    #define zzCMap_at(n) (((n) & 0xF800) == 0xD800 ? zzCMapFallback : zzCMapL[n])
+#endif
+
     const int32_t* zzTransL = ZZ_TRANS();
     const int32_t* zzRowMapL = ZZ_ROWMAP();
     const int32_t* zzAttrL = ZZ_ATTRIBUTE();
@@ -458,7 +472,7 @@ int32_t StandardTokenizerImpl::getNextToken() {
                 }
             }
 
-            int32_t zzNext = zzTransL[zzRowMapL[zzState] + zzCMapL[zzInput]];
+            int32_t zzNext = zzTransL[zzRowMapL[zzState] + zzCMap_at(zzInput)];
             if (zzNext == -1) {
                 break;
             }
