@@ -61,7 +61,7 @@ public:
     virtual void seek(const TermPtr& term);
     virtual void seek(const TermEnumPtr& termEnum);
     virtual bool next();
-    virtual int32_t read(Collection<int32_t> docs, Collection<int32_t> freqs);
+    virtual int32_t read(Collection<int32_t>& docs, Collection<int32_t>& freqs);
     virtual bool skipTo(int32_t target);
     virtual void close();
 };
