@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-// Copyright (c) 2009-2011 Alan Wright. All rights reserved.
+// Copyright (c) 2009-2014 Alan Wright. All rights reserved.
 // Distributable under the terms of either the Apache License (Version 2.0)
 // or the GNU Lesser General Public License.
 /////////////////////////////////////////////////////////////////////////////
@@ -9,17 +9,17 @@
 
 #include "LuceneObject.h"
 
-namespace Lucene
-{
-    class StandardAnalyzerSavedStreams : public LuceneObject
-    {
-    public:
-        virtual ~StandardAnalyzerSavedStreams();
-    
-    public:
-        StandardTokenizerPtr tokenStream;
-        TokenStreamPtr filteredTokenStream;
-    };
+namespace Lucene {
+
+class StandardAnalyzerSavedStreams : public LuceneObject {
+public:
+    virtual ~StandardAnalyzerSavedStreams();
+
+public:
+    StandardTokenizerPtr tokenStream;
+    TokenStreamPtr filteredTokenStream;
+};
+
 }
 
 #endif
