@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-// Copyright (c) 2009-2011 Alan Wright. All rights reserved.
+// Copyright (c) 2009-2014 Alan Wright. All rights reserved.
 // Distributable under the terms of either the Apache License (Version 2.0)
 // or the GNU Lesser General Public License.
 /////////////////////////////////////////////////////////////////////////////
@@ -7,9 +7,9 @@
 #include "LuceneInc.h"
 #include "FormatPostingsDocsConsumer.h"
 
-namespace Lucene
-{
-    FormatPostingsDocsConsumer::~FormatPostingsDocsConsumer()
-    {
-    }
+namespace Lucene {
+
+FormatPostingsDocsConsumer::~FormatPostingsDocsConsumer() {
+}
+
 }
