@@ -27,23 +27,25 @@ PhraseScorer::PhraseScorer(const WeightPtr& weight, Collection<TermPositionsPtr>
     // This allows to easily identify a matching (exact) phrase when all PhrasePositions have exactly the same position.
     for (int32_t i = 0; i < tps.size(); ++i) {
         PhrasePositionsPtr pp(newLucene<PhrasePositions>(tps[i], offsets[i]));
-        if (last) { // add next to end of list
-            last->_next = pp;
+        auto* __pp = pp.get();
+        if (__last) { // add next to end of list
+            __last->__next = __pp;
         } else {
-            first = pp;
+            __first = __pp;
         }
-        last = pp;
+        __last = __pp;
+        _holds.emplace_back(pp);
     }
 
     pq = newLucene<PhraseQueue>(tps.size()); // construct empty pq
-    first->doc = -1;
+    __first->doc = -1;
 }
 
 PhraseScorer::~PhraseScorer() {
 }
 
 int32_t PhraseScorer::docID() {
-    return first->doc;
+    return __first->doc;
 }
 
 int32_t PhraseScorer::nextDoc() {
@@ -51,18 +53,18 @@ int32_t PhraseScorer::nextDoc() {
         init();
         firstTime = false;
     } else if (more) {
-        more = last->next();    // trigger further scanning
+        more = __last->next();    // trigger further scanning
     }
     if (!doNext()) {
-        first->doc = NO_MORE_DOCS;
+        __first->doc = NO_MORE_DOCS;
     }
-    return first->doc;
+    return __first->doc;
 }
 
 bool PhraseScorer::doNext() {
     while (more) {
-        while (more && first->doc < last->doc) { // find doc with all the terms
-            more = first->skipTo(last->doc); // skip first upto last and move it to the end
+        while (more && __first->doc < __last->doc) { // find doc with all the terms
+            more = __first->skipTo(__last->doc); // skip first upto last and move it to the end
             firstToLast();
         }
 
@@ -70,7 +72,7 @@ bool PhraseScorer::doNext() {
             // found a doc with all of the terms
             freq = phraseFreq(); // check for phrase
             if (freq == 0.0) { // no match
-                more = last->next();    // trigger further scanning
+                more = __last->next();    // trigger further scanning
             } else {
                 return true;
             }
@@ -81,21 +83,21 @@ bool PhraseScorer::doNext() {
 
 double PhraseScorer::score() {
     double raw = getSimilarity()->tf(freq) * value; // raw score
-    return !norms ? raw : raw * Similarity::decodeNorm(norms[first->doc]); // normalize
+    return !norms ? raw : raw * Similarity::decodeNorm(norms[__first->doc]); // normalize
 }
 
 int32_t PhraseScorer::advance(int32_t target) {
     firstTime = false;
-    for (PhrasePositionsPtr pp(first); more && pp; pp = pp->_next) {
-        more = pp->skipTo(target);
+    for (auto* __pp = __first; more && __pp; __pp = __pp->__next) {
+        more = __pp->skipTo(target);
     }
     if (more) {
         sort();    // re-sort
     }
     if (!doNext()) {
-        first->doc = NO_MORE_DOCS;
+        __first->doc = NO_MORE_DOCS;
     }
-    return first->doc;
+    return __first->doc;
 }
 
 double PhraseScorer::currentFreq() {
@@ -103,8 +105,8 @@ double PhraseScorer::currentFreq() {
 }
 
 void PhraseScorer::init() {
-    for (PhrasePositionsPtr pp(first); more && pp; pp = pp->_next) {
-        more = pp->next();
+    for (auto* __pp = __first; more && __pp; __pp = __pp->__next) {
+        more = __pp->next();
     }
     if (more) {
         sort();
@@ -113,32 +115,32 @@ void PhraseScorer::init() {
 
 void PhraseScorer::sort() {
     pq->clear();
-    for (PhrasePositionsPtr pp(first); more && pp; pp = pp->_next) {
-        pq->add(pp);
+    for (auto* __pp = __first; more && __pp; __pp = __pp->__next) {
+        pq->add(__pp);
     }
     pqToList();
 }
 
 void PhraseScorer::pqToList() {
-    last.reset();
-    first.reset();
+    __last = nullptr;
+    __first = nullptr;
     while (pq->top()) {
-        PhrasePositionsPtr pp(pq->pop());
-        if (last) { // add next to end of list
-            last->_next = pp;
+        auto* __pp = pq->pop();
+        if (__last) { // add next to end of list
+            __last->__next = __pp;
         } else {
-            first = pp;
+            __first = __pp;
         }
-        last = pp;
-        pp->_next.reset();
+        __last = __pp;
+        __pp->__next = nullptr;
     }
 }
 
 void PhraseScorer::firstToLast() {
-    last->_next = first; // move first to end of list
-    last = first;
-    first = first->_next;
-    last->_next.reset();
+    __last->__next = __first; // move first to end of list
+    __last = __first;
+    __first = __first->__next;
+    __last->__next = nullptr;
 }
 
 String PhraseScorer::toString() {
