@@ -60,6 +60,7 @@ void TopScoreDocCollector::setNextReader(const IndexReaderPtr& reader, int32_t d
 
 void TopScoreDocCollector::setScorer(const ScorerPtr& scorer) {
     this->_scorer = scorer;
+    this->__scorer = scorer.get();
 }
 
 InOrderTopScoreDocCollector::InOrderTopScoreDocCollector(int32_t numHits) : TopScoreDocCollector(numHits) {
@@ -69,7 +70,7 @@ InOrderTopScoreDocCollector::~InOrderTopScoreDocCollector() {
 }
 
 void InOrderTopScoreDocCollector::collect(int32_t doc) {
-    double score = ScorerPtr(_scorer)->score();
+    double score = __scorer->score();
 
     // This collector cannot handle these scores
     BOOST_ASSERT(score != -std::numeric_limits<double>::infinity());
@@ -98,7 +99,7 @@ OutOfOrderTopScoreDocCollector::~OutOfOrderTopScoreDocCollector() {
 }
 
 void OutOfOrderTopScoreDocCollector::collect(int32_t doc) {
-    double score = ScorerPtr(_scorer)->score();
+    double score = __scorer->score();
 
     // This collector cannot handle NaN
     BOOST_ASSERT(!MiscUtils::isNaN(score));
