@@ -22,10 +22,12 @@ AttributePtr AttributeFactory::createAttributeInstance(const String& className)
 
 AttributeFactoryPtr AttributeFactory::DEFAULT_ATTRIBUTE_FACTORY() {
     static AttributeFactoryPtr _DEFAULT_ATTRIBUTE_FACTORY;
-    if (!_DEFAULT_ATTRIBUTE_FACTORY) {
+
+    LUCENE_RUN_ONCE(
         _DEFAULT_ATTRIBUTE_FACTORY = newLucene<DefaultAttributeFactory>();
         CycleCheck::addStatic(_DEFAULT_ATTRIBUTE_FACTORY);
-    }
+    );
+    
     return _DEFAULT_ATTRIBUTE_FACTORY;
 }
 
