@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-// Copyright (c) 2009-2011 Alan Wright. All rights reserved.
+// Copyright (c) 2009-2014 Alan Wright. All rights reserved.
 // Distributable under the terms of either the Apache License (Version 2.0)
 // or the GNU Lesser General Public License.
 /////////////////////////////////////////////////////////////////////////////
@@ -11,18 +11,15 @@
 
 using namespace Lucene;
 
-BOOST_FIXTURE_TEST_SUITE(TermTest, LuceneTestFixture)
+typedef LuceneTestFixture TermTest;
 
-BOOST_AUTO_TEST_CASE(testEquals)
-{
+TEST_F(TermTest, testEquals) {
     TermPtr base = newLucene<Term>(L"same", L"same");
     TermPtr same = newLucene<Term>(L"same", L"same");
     TermPtr differentField = newLucene<Term>(L"different", L"same");
     TermPtr differentText = newLucene<Term>(L"same", L"different");
-    BOOST_CHECK(base->equals(base));
-    BOOST_CHECK(base->equals(same));
-    BOOST_CHECK(!base->equals(differentField));
-    BOOST_CHECK(!base->equals(differentText));
+    EXPECT_TRUE(base->equals(base));
+    EXPECT_TRUE(base->equals(same));
+    EXPECT_TRUE(!base->equals(differentField));
+    EXPECT_TRUE(!base->equals(differentText));
 }
-
-BOOST_AUTO_TEST_SUITE_END()
